@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 Puppet::Type.newtype(:postgresql_psql) do
   newparam(:name) do
     desc 'An arbitrary tag for your own reference; the name of the message.'
@@ -21,7 +23,7 @@ Puppet::Type.newtype(:postgresql_psql) do
 
     def sync
       output, status = provider.run_sql_command(value)
-      raise("Error executing SQL; psql returned #{status}: '#{output}'") unless status == 0 # rubocop:disable Style/NumericPredicate
+      raise("Error executing SQL; psql returned #{status}: '#{output}'") unless status.to_i.zero?
     end
   end
 
@@ -36,13 +38,11 @@ Puppet::Type.newtype(:postgresql_psql) do
     # Return true if a matching row is found
     def matches(value)
       output, status = provider.run_unless_sql_command(value)
-      # rubocop:disable Style/NumericPredicate
-      fail("Error evaluating 'unless' clause, returned #{status}: '#{output}'") unless status == 0 # rubocop:disable Style/SignalException
-      # rubocop:enable Style/NumericPredicate
+      fail("Error evaluating 'unless' clause, returned #{status}: '#{output}'") unless status.to_i.zero? # rubocop:disable Style/SignalException
 
       result_count = output.strip.to_i
       debug("Found #{result_count} row(s) executing 'unless' clause")
-      result_count > 0
+      result_count.positive?
     end
   end
 
@@ -59,11 +59,11 @@ Puppet::Type.newtype(:postgresql_psql) do
       output, status = provider.run_unless_sql_command(value)
       status = output.exitcode if status.nil?
 
-      raise("Error evaluating 'onlyif' clause, returned #{status}: '#{output}'") unless status == 0 # rubocop:disable Style/NumericPredicate
+      raise("Error evaluating 'onlyif' clause, returned #{status}: '#{output}'") unless status.to_i.zero?
 
       result_count = output.strip.to_i
       debug("Found #{result_count} row(s) executing 'onlyif' clause")
-      result_count > 0
+      result_count.positive?
     end
   end
 
@@ -110,9 +110,7 @@ Puppet::Type.newtype(:postgresql_psql) do
 
     validate do |values|
       Array(values).each do |value|
-        unless value =~ %r{\w+=}
-          raise ArgumentError, "Invalid environment setting '#{value}'"
-        end
+        raise ArgumentError, "Invalid environment setting '#{value}'" unless %r{\w+=}.match?(value)
       end
     end
   end
@@ -124,7 +122,25 @@ Puppet::Type.newtype(:postgresql_psql) do
     newvalues(:true, :false)
   end
 
-  autorequire(:class) { ['Postgresql::Server::Service'] }
+  newparam(:instance) do
+    desc 'The postgresql instance under which the psql command should be executed.'
+    defaultto('main')
+  end
+
+  newparam(:sensitive, boolean: true) do
+    desc "If 'true', then the executed command will not be echoed into the log. Use this to protect sensitive information passing through."
+
+    defaultto(:false)
+    newvalues(:true, :false)
+  end
+
+  autorequire(:anchor) do
+    ["postgresql::server::service::begin::#{self[:instance]}"]
+  end
+
+  autorequire(:service) do
+    ["postgresqld_instance_#{self[:instance]}"]
+  end
 
   def should_run_sql(refreshing = false)
     onlyif_param = @parameters[:onlyif]
@@ -132,10 +148,22 @@ Puppet::Type.newtype(:postgresql_psql) do
     return false if !onlyif_param.nil? && !onlyif_param.value.nil? && !onlyif_param.matches(onlyif_param.value)
     return false if !unless_param.nil? && !unless_param.value.nil? && unless_param.matches(unless_param.value)
     return false if !refreshing && @parameters[:refreshonly].value == :true
+
     true
   end
 
   def refresh
     property(:command).sync if should_run_sql(true)
   end
+
+  private
+
+  def set_sensitive_parameters(sensitive_parameters)
+    # Respect sensitive commands
+    if sensitive_parameters.include?(:unless)
+      sensitive_parameters.delete(:unless)
+      parameter(:unless).sensitive = true
+    end
+    super(sensitive_parameters)
+  end
 end
